#ifndef __msp430_headers_timera_h
#define __msp430_headers_timera_h

/* timera.h
 *
 * mspgcc project: MSP430 device headers
 * TIMERA module header
 *
 * (c) 2002 by M. P. Ashton <data@ieee.org>
 * Originally based in part on work by Texas Instruments Inc.
 *
 * $Id: timera.h,v 1.4 2002/12/28 06:50:47 coppice Exp $
 */

/* Switches: none */

#define TAIV_               0x012E  /* Timer A Interrupt Vector Word */
sfrw (TAIV,TAIV_);
#define TACTL_              0x0160  /* Timer A Control */
sfrw (TACTL,TACTL_);
#define TACCTL0_            0x0162  /* Timer A Capture/Compare Control 0 */
sfrw (TACCTL0,TACCTL0_);
#define TACCTL1_            0x0164  /* Timer A Capture/Compare Control 1 */
sfrw (TACCTL1,TACCTL1_);
#define TACCTL2_            0x0166  /* Timer A Capture/Compare Control 2 */
sfrw (TACCTL2,TACCTL2_);
#define TAR_                0x0170  /* Timer A */
sfrw (TAR,TAR_);
#define TACCR0_             0x0172  /* Timer A Capture/Compare 0 */
sfrw (TACCR0,TACCR0_);
#define TACCR1_             0x0174  /* Timer A Capture/Compare 1 */
sfrw (TACCR1,TACCR1_);
#define TACCR2_             0x0176  /* Timer A Capture/Compare 2 */
sfrw (TACCR2,TACCR2_);

/* Alternate register names */
#define CCTL0_              0x0162  /* Timer A Capture/Compare Control 0 */
sfrw (CCTL0,CCTL0_);
#define CCTL1_              0x0164  /* Timer A Capture/Compare Control 1 */
sfrw (CCTL1,CCTL1_);
#define CCTL2_              0x0166  /* Timer A Capture/Compare Control 2 */
sfrw (CCTL2,CCTL2_);
#define CCR0_               0x0172  /* Timer A Capture/Compare 0 */
sfrw (CCR0,CCR0_);
#define CCR1_               0x0174  /* Timer A Capture/Compare 1 */
sfrw (CCR1,CCR1_);
#define CCR2_               0x0176  /* Timer A Capture/Compare 2 */
sfrw (CCR2,CCR2_);

#define TASSEL2             0x0400  /* unused */        /* to distinguish from UART SSELx */
#define TASSEL1             0x0200  /* Timer A clock source select 0 */
#define TASSEL0             0x0100  /* Timer A clock source select 1 */
#define ID1                 0x0080  /* Timer A clock input devider 1 */
#define ID0                 0x0040  /* Timer A clock input devider 0 */
#define MC1                 0x0020  /* Timer A mode control 1 */
#define MC0                 0x0010  /* Timer A mode control 0 */
#define TACLR               0x0004  /* Timer A counter clear */
#define TAIE                0x0002  /* Timer A counter interrupt enable */
#define TAIFG               0x0001  /* Timer A counter interrupt flag */

#define MC_0                (0<<4)  /* Timer A mode control: 0 - Stop */
#define MC_1                (1<<4)  /* Timer A mode control: 1 - Up to CCR0 */
#define MC_2                (2<<4)  /* Timer A mode control: 2 - Continous up */
#define MC_3                (3<<4)  /* Timer A mode control: 3 - Up/Down */
#define ID_0                (0<<6)  /* Timer A input divider: 0 - /1 */
#define ID_1                (1<<6)  /* Timer A input divider: 1 - /2 */
#define ID_2                (2<<6)  /* Timer A input divider: 2 - /4 */
#define ID_3                (3<<6)  /* Timer A input divider: 3 - /8 */
#define TASSEL_0            (0<<8)  /* Timer A clock source select: 0 - TACLK */
#define TASSEL_1            (1<<8)  /* Timer A clock source select: 1 - ACLK  */
#define TASSEL_2            (2<<8)  /* Timer A clock source select: 2 - SMCLK */
#define TASSEL_3            (3<<8)  /* Timer A clock source select: 3 - INCLK */

#define CM1                 0x8000  /* Capture mode 1 */
#define CM0                 0x4000  /* Capture mode 0 */
#define CCIS1               0x2000  /* Capture input select 1 */
#define CCIS0               0x1000  /* Capture input select 0 */
#define SCS                 0x0800  /* Capture sychronize */
#define SCCI                0x0400  /* Latched capture signal (read) */
#define CAP                 0x0100  /* Capture mode: 1 /Compare mode : 0 */
#define OUTMOD2             0x0080  /* Output mode 2 */
#define OUTMOD1             0x0040  /* Output mode 1 */
#define OUTMOD0             0x0020  /* Output mode 0 */
#define CCIE                0x0010  /* Capture/compare interrupt enable */
#define CCI                 0x0008  /* Capture input signal (read) */
#define OUT                 0x0004  /* PWM Output signal if output mode 0 */
#define COV                 0x0002  /* Capture/compare overflow flag */
#define CCIFG               0x0001  /* Capture/compare interrupt flag */

#define OUTMOD_0            (0<<5)  /* PWM output mode: 0 - output only */
#define OUTMOD_1            (1<<5)  /* PWM output mode: 1 - set */
#define OUTMOD_2            (2<<5)  /* PWM output mode: 2 - PWM toggle/reset */
#define OUTMOD_3            (3<<5)  /* PWM output mode: 3 - PWM set/reset */
#define OUTMOD_4            (4<<5)  /* PWM output mode: 4 - toggle */
#define OUTMOD_5            (5<<5)  /* PWM output mode: 5 - Reset */
#define OUTMOD_6            (6<<5)  /* PWM output mode: 6 - PWM toggle/set */
#define OUTMOD_7            (7<<5)  /* PWM output mode: 7 - PWM reset/set */
#define CCIS_0              (0<<12) /* Capture input select: 0 - CCIxA */
#define CCIS_1              (1<<12) /* Capture input select: 1 - CCIxB */
#define CCIS_2              (2<<12) /* Capture input select: 2 - GND */
#define CCIS_3              (3<<12) /* Capture input select: 3 - Vcc */
#define CM_0                (0<<14) /* Capture mode: 0 - disabled */
#define CM_1                (1<<14) /* Capture mode: 1 - pos. edge */
#define CM_2                (2<<14) /* Capture mode: 1 - neg. edge */
#define CM_3                (3<<14) /* Capture mode: 1 - both edges */

/* Aliases by mspgcc */
#define MC_STOP             MC_0
#define MC_UPTO_CCR0        MC_1
#define MC_CONT             MC_2
#define MC_UPDOWN           MC_3

#define ID_DIV1             ID_0
#define ID_DIV2             ID_1
#define ID_DIV4             ID_2
#define ID_DIV8             ID_3

#define TASSEL_TACLK        TASSEL_0
#define TASSEL_ACLK         TASSEL_1
#define TASSEL_SMCLK        TASSEL_2
#define TASSEL_INCLK        TASSEL_3

#define OUTMOD_OUT          OUTMOD_0
#define OUTMOD_SET          OUTMOD_1
#define OUTMOD_TOGGLE_RESET OUTMOD_2
#define OUTMOD_SET_RESET    OUTMOD_3
#define OUTMOD_TOGGLE       OUTMOD_4
#define OUTMOD_RESET        OUTMOD_5
#define OUTMOD_TOGGLE_SET   OUTMOD_6
#define OUTMOD_RESET_SET    OUTMOD_7

#define CM_DISABLE          CM_0
#define CM_POS              CM_1
#define CM_NEG              CM_2
#define CM_BOTH             CM_3

#endif
